# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *
import xml.etree.ElementTree as ET
from datetime import datetime

def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies_from_wapt_console()
    if not proxies:
        proxies = get_proxies()
    
    # Récupérer les données depuis l'URL et décoder en tant que chaîne de caractères
    sitewebdata = wgets("https://dl.datalust.co/")
    
    # Parser le XML en prenant en compte l'espace de noms
    tree = ET.ElementTree(ET.fromstring(sitewebdata))
    root = tree.getroot()
    namespace = {'ns': 'http://doc.s3.amazonaws.com/2006-03-01'}

    # Trouver tous les éléments "Contents" en tenant compte de l'espace de noms
    contents = root.findall('ns:Contents', namespace)
    
    if not contents:
        raise ValueError("No contents found in the XML data.")
    
    latest_content = None
    latest_date = None

    for content in contents:
        key = content.find('ns:Key', namespace).text
        last_modified = content.find('ns:LastModified', namespace).text
        date_modified = datetime.strptime(last_modified, "%Y-%m-%dT%H:%M:%S.%fZ")

        if latest_date is None or date_modified > latest_date:
            latest_date = date_modified
            latest_content = content

    if latest_content is None:
        raise ValueError("No valid content found in the XML data.")
    
    latest_version = latest_content.find('ns:Key', namespace).text.split('/')[0]
    download_url = f"https://dl.datalust.co/{latest_version}/win-x64/Seq-{latest_version}.msi"
    latest_bin = download_url.split("/")[-1]

    
    if not isfile(latest_bin):
        package_updated = True
        wget(download_url, latest_bin, proxies=proxies)

    for f in glob.glob("*.msi"):
        if f != latest_bin:
            remove_file(f)    

    version =get_version_from_binary(latest_bin)
    # Updating the package
    control.set_software_version(version)
    control.save_control_to_wapt()

